==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_functions/mp0113_001/ParentPK.java <==

package net.datastream.schemas.mp_functions.mp0113_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="pkcolumnname" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="pkvalue" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "ParentPK")
public class ParentPK {

    @XmlAttribute(name = "pkcolumnname")
    protected String pkcolumnname;
    @XmlAttribute(name = "pkvalue")
    protected String pkvalue;

    /**
     * Obtient la valeur de la propriété pkcolumnname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPkcolumnname() {
        return pkcolumnname;
    }

    /**
     * Définit la valeur de la propriété pkcolumnname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPkcolumnname(String value) {
        this.pkcolumnname = value;
    }

    /**
     * Obtient la valeur de la propriété pkvalue.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPkvalue() {
        return pkvalue;
    }

    /**
     * Définit la valeur de la propriété pkvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPkvalue(String value) {
        this.pkvalue = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_functions/mp0113_001/ParentPK.java <==

package net.datastream.schemas.mp_functions.mp0113_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="pkcolumnname" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="pkvalue" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "ParentPK")
public class ParentPK {

    @XmlAttribute(name = "pkcolumnname")
    protected String pkcolumnname;
    @XmlAttribute(name = "pkvalue")
    protected String pkvalue;

    /**
     * Gets the value of the pkcolumnname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPkcolumnname() {
        return pkcolumnname;
    }

    /**
     * Sets the value of the pkcolumnname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPkcolumnname(String value) {
        this.pkcolumnname = value;
    }

    /**
     * Gets the value of the pkvalue property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPkvalue() {
        return pkvalue;
    }

    /**
     * Sets the value of the pkvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPkvalue(String value) {
        this.pkvalue = value;
    }

}
